@@ -15,6 +15,8 @@ pub enum LinderaErrorKind {
     DictionaryNotFound,
     DictionaryLoadError,
     DictionaryBuildError,
+    DictionaryTypeError,
+    UserDictionaryTypeError,
 }
 
 impl LinderaErrorKind {
